#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-BRmHofT5nEWKcylWp8tw8R
key:                  ordered-containers-0.2.4-BRmHofT5nEWKcylWp8tw8R
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  6b4df96e7466c933ba38c84de63f92eb
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-BRmHofT5nEWKcylWp8tw8R
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-CNoNcGLK9KJ5X5nXfJeai3

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

